@@ -21,7 +21,10 @@ SEXP _babelmixr2_popedMultipleEndpointResetTimeIndex(void);
 SEXP _babelmixr2_popedMultipleEndpointIndexDataFrame(SEXP);
 SEXP _babelmixr2_popedMultipleEndpointParam(SEXP, SEXP, SEXP, SEXP, SEXP);
 
+SEXP _babelmixr2_popedGetLoadedInfo(void);
+
 static const R_CallMethodDef CallEntries[] = {
+  {"_babelmixr2_popedGetLoadedInfo", (DL_FUNC) &_babelmixr2_popedGetLoadedInfo, 0},
   {"_babelmixr2_popedMultipleEndpointParam",
    (DL_FUNC) &_babelmixr2_popedMultipleEndpointParam, 5},
   {"_babelmixr2_popedMultipleEndpointIndexDataFrame", (DL_FUNC) &_babelmixr2_popedMultipleEndpointIndexDataFrame, 1},
